#!/bin/bash

#--- setup

tab="$1"
dir="$2"
orig="$dir/.orig"
tools="cut mkdir ln wstrt"

#[[ -s $tab ]] || echo "tab not found: $tab"
#[[ -d $dir ]] || echo "dir not found: $dir"

[[ -s $tab && -d $dir ]] || exit 0


#--- check tools

let err=0
for tool in $tools
do
    if ! which "$tool" >/dev/null 2>&1
    then
	let err++
	echo "${0##*/}: Missing tool: $tool" >&2
    fi
done
((err)) && exit 1


#--- create a ".orig" directory, don't overwrite (important if called twice)

mkdir -p "$orig"
for f in $( wstrt files | cut -d' ' -f3,4 )
do
    s="$dir/$f.brstm"
    d="$orig/$f.brstm"
    [[ -f $s && ! -f $d ]] && ln -f "$s" "$d"
done


#--- assign sound files using the assigning table

while IFS='= ' read dname sname
do
    sname="${sname%%#*}"
    dname="${dname%%#*}"
    [[ $sname == "" || $dname == "" ]] && continue

    src=($( wstrt find -ll +track "$sname" | cut -d' ' -f1,3,4 ))
    dst=($( wstrt find -ll +track "$dname" | cut -d' ' -f1,3,4 ))
    #echo "|${src[*]}|${dst[*]}|"

    for i in 1 2
    do
	s="$orig/${src[i]}.brstm"
	d="$dir/${dst[i]}.brstm"
	if [[ -f $s && -f $d ]]
	then
	    dst="${dst//[!0-9]/}"
	    src="${src//[!0-9]/}"
	    stat="$(awk " /$dst,$src/ {print \$2}" mkw-sound.db)"
	    ((i==1)) || echo " * sound:  $dst=$src [$stat], $dname := $sname"
	    ln -f "$s" "$d"
	fi
    done

done < "$tab"


#--- all done

exit 0
